﻿using System;
using Unity;
using Unity.Lifetime;

namespace ModelTools.BusinessLogics
{
	public class UnityContainerConfigurator
	{
		private static IUnityContainer _unityContainer;

		public static IUnityContainer Container
		{
			get
			{
				if (_unityContainer == null) _unityContainer = new UnityContainer(); 
				return _unityContainer;
			}
		}

		/// <summary>
		/// Инициализация сервисов
		/// </summary>        
		public static void InitServices()
		{
			var ext = ServiceProviderLoader.GetImplementationExtensions();
			if (ext.Count == 0)
			{
				throw new ArgumentNullException("Отсутствуют компоненты для загрузки зависимостей по модулям");
			}
			// регистрируем в UnityContainaer зависимости
			foreach (var e in ext)
			{
				e.RegisterServices();
			}
		}

		public static void PublishService<T, U>() where U : T => Container.RegisterType<T, U>(new HierarchicalLifetimeManager());

		public static void PublishService<T>() => Container.RegisterType<T>(new HierarchicalLifetimeManager());

		public static void PublishService(Type t) => Container.RegisterType(t);

		public static T Resolve<T>() => Container.Resolve<T>();
	}
}